@@ -227,10 +227,10 @@ def get_parser():
             default=None,
         )
         command.add_argument(
-            "--container_tech",
+            "--container-tech",
             dest="container_tech",
             help="container technology to use to override settings.yaml",
-            choices=["singularity", "podman"],
+            choices=["singularity", "podman", "docker"],
             default=None,
         )
 
